@@ -2,6 +2,7 @@
 namespace Blue2\Scruffy;
 use Blue2\Scruffy\Controllers\MaintenanceController;
 use Blue2\Scruffy\Controllers\SiteController;
+use Blue2\Scruffy\Controllers\MapController;
 
 class Site extends \Blue2\Common\Site
 {
@@ -146,6 +147,8 @@ class Site extends \Blue2\Common\Site
         add_filter( 'register_post_type_args', [$this, 'change_post_slugs'], 10, 2 );
 
         add_filter('excerpt_more', [$this, 'tidyExcerpt']);
+
+        add_filter( 'get_the_archive_title', [$this,'mlv_archive_title'] );
     }
 
     private function registerActions() {
@@ -171,6 +174,7 @@ class Site extends \Blue2\Common\Site
     private function setupControllers(){
         new MaintenanceController();
         new SiteController();
+        new MapController();
     }
 
     public function registerPostTypes()
@@ -179,6 +183,7 @@ class Site extends \Blue2\Common\Site
         Post\Lodge::registerPostType();
         Post\Plot::registerPostType();
         Post\Experience::registerPostType();
+        Post\Team::registerPostType();
     }
 
     public function registerCustomTaxonomy() 
@@ -219,6 +224,7 @@ class Site extends \Blue2\Common\Site
         add_image_size('card', '500', '300', true);
         add_image_size('article', '530', '375', true);
         add_image_size('slider', '850', '850', true);
+        add_image_size('team-member', 360, 440, ['center', 'center']);
     }
 
     public function change_plot_link( $post_link, $id = 0 ) {
@@ -291,6 +297,29 @@ class Site extends \Blue2\Common\Site
                     'key' => $term->slug . '-group',
                     'title' => 'Location Information',
                     'fields' => array(
+                        array(
+                            'key' => $term->slug . '-message',
+                            'label' => 'Message',
+                            'name' => '',
+                            'type' => 'message',
+                            'instructions' => '',
+                            'required' => 0,
+                            'conditional_logic' => 0,
+                            'wrapper' => array(
+                                'width' => '',
+                                'class' => '',
+                                'id' => '',
+                            ),
+                            'message' => 'These are the location settings for ' . $term->name . '.
+                
+                These are the tabs that are found on the locations page for ' . $term->name . '. 
+                
+                The site plan is the image used for the image map on the locations page.
+                
+                The 3d walkthrough is the matterport link provided, and the location is a Google Embed code you can get from the share section of Google Maps.',
+                            'new_lines' => 'wpautop',
+                            'esc_html' => 0,
+                        ),
                         array(
                             'key' => $term->slug . '-site-plan',
                             'label' => 'Site Plan',
@@ -320,7 +349,7 @@ class Site extends \Blue2\Common\Site
                                 'class' => '',
                                 'id' => '',
                             ),
-                            'return_format' => 'id',
+                            'return_format' => 'url',
                             'preview_size' => 'medium',
                             'library' => 'all',
                             'min_width' => '',
@@ -351,8 +380,8 @@ class Site extends \Blue2\Common\Site
                             'key' => $term->slug . '-matterport-code',
                             'label' => 'Matterport Code',
                             'name' => $term->slug . '-matterport-code',
-                            'type' => 'wysiwyg',
-                            'instructions' => '',
+                            'type' => 'text',
+                            'instructions' => 'Enter the link to the matterport video',
                             'required' => 0,
                             'conditional_logic' => 0,
                             'wrapper' => array(
@@ -386,8 +415,8 @@ class Site extends \Blue2\Common\Site
                             'key' => $term->slug . '-google-maps',
                             'label' => 'Location',
                             'name' => $term->slug . '-location',
-                            'type' => 'google_map',
-                            'instructions' => '',
+                            'type' => 'wysiwyg',
+                            'instructions' => 'Paste in your Google Maps embed code',
                             'required' => 0,
                             'conditional_logic' => 0,
                             'wrapper' => array(
@@ -395,10 +424,11 @@ class Site extends \Blue2\Common\Site
                                 'class' => '',
                                 'id' => '',
                             ),
-                            'center_lat' => '',
-                            'center_lng' => '',
-                            'zoom' => '',
-                            'height' => '',
+                            'default_value' => '',
+                            'tabs' => 'all',
+                            'toolbar' => 'full',
+                            'media_upload' => 1,
+                            'delay' => 0,
                         ),
                     ),
                     'location' => $acfLocations,
@@ -419,13 +449,14 @@ class Site extends \Blue2\Common\Site
         //only do this on search
         if (is_search()) {
             //first check for the first type if not set then its the default post.
-            $post_type = $_GET['post_type'];
+            $post_type = 'plot';
 
-            if (!$post_type) {
-                $post_type = 'lodge';
-            }
+            if ($query->get('post_type') == 'nav_menu_item')
+                return $query;
 
-            $query->set('post_type', $post_type);
+            if ($query->is_search) {
+                $query->set('post_type', $post_type );
+            };
     
             if (isset($_GET['resort'])){
                 $query->set('locations', $_GET['resort']);
@@ -451,7 +482,7 @@ class Site extends \Blue2\Common\Site
             }
 
             $metaQuery[] = [
-                'key' => 'lodge_status',
+                'key' => 'plot_status',
                 'value' => 'sale',
                 'compare' => 'LIKE'
             ];
@@ -476,4 +507,20 @@ class Site extends \Blue2\Common\Site
         }
         return $options;
     }
+
+    public function mlv_archive_title( $title ) {
+        if ( is_category() ) {
+            $title = single_cat_title( '', false );
+        } elseif ( is_tag() ) {
+            $title = single_tag_title( '', false );
+        } elseif ( is_author() ) {
+            $title = '<span class="vcard">' . get_the_author() . '</span>';
+        } elseif ( is_post_type_archive() ) {
+            $title = post_type_archive_title( '', false );
+        } elseif ( is_tax() ) {
+            $title = single_term_title( '', false );
+        }
+    
+        return $title;
+    }
 }  
\ No newline at end of file
